@@ -1,4 +1,4 @@
-struct ClosureBodyLengthRule: OptInRule, SwiftSyntaxRule, ConfigurationProviderRule {
+struct ClosureBodyLengthRule: OptInRule, SwiftSyntaxRule {
     var configuration = SeverityLevelsConfiguration<Self>(warning: 30, error: 100)
 
     static let description = RuleDescription(
@@ -10,7 +10,7 @@ struct ClosureBodyLengthRule: OptInRule, SwiftSyntaxRule, ConfigurationProviderR
         triggeringExamples: ClosureBodyLengthRuleExamples.triggeringExamples
     )
 
-    func makeVisitor(file: SwiftLintFile) -> ViolationsSyntaxVisitor {
+    func makeVisitor(file: SwiftLintFile) -> ViolationsSyntaxVisitor<ConfigurationType> {
         BodyLengthRuleVisitor(kind: .closure, file: file, configuration: configuration)
     }
 }
