@@ -7,8 +7,7 @@ public extension Configuration {
         case spaces(count: Int)
 
         /// The default indentation style if none is explicitly provided.
-        @_spi(TestHelper)
-        public static var `default` = spaces(count: 4)
+        package static let `default` = spaces(count: 4)
 
         /// Creates an indentation style based on an untyped configuration value.
         ///
