@@ -17,7 +17,10 @@ private let outputQueue: DispatchQueue = {
 
 private func setupAtExitHandler() {
     atexit {
-        outputQueue.sync(flags: .barrier) {}
+        // Ensure all queued output is written before exiting.
+        outputQueue.sync(flags: .barrier) {
+            // Just wait.
+        }
     }
 }
 
@@ -26,7 +29,7 @@ private func setupAtExitHandler() {
 
  - parameter object: Object to print.
  */
-public func queuedPrint<T>(_ object: T) {
+public func queuedPrint<T: Sendable>(_ object: T) {
     outputQueue.async {
         print(object)
     }
