@@ -2,10 +2,10 @@ internal struct HashableConfigurationRuleWrapperWrapper: Hashable {
     let configurationRuleWrapper: ConfigurationRuleWrapper
 
     static func == (
-        lhs: HashableConfigurationRuleWrapperWrapper, rhs: HashableConfigurationRuleWrapperWrapper
+        lhs: Self, rhs: Self
     ) -> Bool {
         // Only use identifier for equality check (not taking config into account)
-        return type(of: lhs.configurationRuleWrapper.rule).description.identifier
+        type(of: lhs.configurationRuleWrapper.rule).description.identifier
             == type(of: rhs.configurationRuleWrapper.rule).description.identifier
     }
 
