@@ -1,4 +1,5 @@
 /// The magnitude of a `StyleViolation`.
+@AcceptableByConfigurationElement
 public enum ViolationSeverity: String, Comparable, Codable, InlinableOptionType {
     /// Non-fatal. If using SwiftLint as an Xcode build phase, Xcode will mark the build as having succeeded.
     case warning
@@ -7,9 +8,7 @@ public enum ViolationSeverity: String, Comparable, Codable, InlinableOptionType
 
     // MARK: Comparable
 
-    public static func < (lhs: ViolationSeverity, rhs: ViolationSeverity) -> Bool {
-        return lhs == .warning && rhs == .error
+    public static func < (lhs: Self, rhs: Self) -> Bool {
+        lhs == .warning && rhs == .error
     }
-
-    public func asOption() -> OptionType { .symbol(rawValue) }
 }
