@@ -1,5 +1,5 @@
 /// A configuration value for a rule to allow users to modify its behavior.
-public protocol RuleConfiguration: InlinableOptionType {
+public protocol RuleConfiguration: Equatable {
     /// The type of the rule that's using this configuration.
     associatedtype Parent: Rule
 
@@ -13,13 +13,6 @@ public protocol RuleConfiguration: InlinableOptionType {
     ///
     /// - throws: Throws if the configuration is not in the expected format.
     mutating func apply(configuration: Any) throws
-
-    /// Whether the specified configuration is equivalent to the current value.
-    ///
-    /// - parameter ruleConfiguration: The rule configuration to compare against.
-    ///
-    /// - returns: Whether the specified configuration is equivalent to the current value.
-    func isEqualTo(_ ruleConfiguration: some RuleConfiguration) -> Bool
 }
 
 /// A configuration for a rule that allows to configure at least the severity.
@@ -35,12 +28,13 @@ public extension SeverityBasedRuleConfiguration {
     }
 }
 
-public extension RuleConfiguration where Self: Equatable {
-    func isEqualTo(_ ruleConfiguration: some RuleConfiguration) -> Bool {
-        return self == ruleConfiguration as? Self
-    }
-}
-
 public extension RuleConfiguration {
     var parameterDescription: RuleConfigurationDescription? { nil }
 }
+
+public extension RuleConfiguration {
+    /// All keys supported by this configuration.
+    var supportedKeys: Set<String> {
+        Set(RuleConfigurationDescription.from(configuration: self).allowedKeys())
+    }
+}
