@@ -2,28 +2,28 @@ import Foundation
 import SourceKittenFramework
 
 /// Reports violations as a JSON array.
-public struct JSONReporter: Reporter {
+struct JSONReporter: Reporter {
     // MARK: - Reporter Conformance
 
-    public static let identifier = "json"
-    public static let isRealtime = false
-    public static let description: String = "Reports violations as a JSON array."
+    static let identifier = "json"
+    static let isRealtime = false
+    static let description = "Reports violations as a JSON array."
 
-    public static func generateReport(_ violations: [StyleViolation]) -> String {
-        return toJSON(violations.map(dictionary(for:)))
+    static func generateReport(_ violations: [StyleViolation]) -> String {
+        toJSON(violations.map(dictionary(for:)), options: [.prettyPrinted, .sortedKeys, .withoutEscapingSlashes])
     }
 
     // MARK: - Private
 
     private static func dictionary(for violation: StyleViolation) -> [String: Any] {
-        return [
+        [
             "file": violation.location.file ?? NSNull() as Any,
             "line": violation.location.line ?? NSNull() as Any,
             "character": violation.location.character ?? NSNull() as Any,
             "severity": violation.severity.rawValue.capitalized,
             "type": violation.ruleName,
             "rule_id": violation.ruleIdentifier,
-            "reason": violation.reason
+            "reason": violation.reason,
         ]
     }
 }
