@@ -1,22 +1,22 @@
 import SourceKittenFramework
 
 /// Reports violations in SonarQube import format.
-public struct SonarQubeReporter: Reporter {
+struct SonarQubeReporter: Reporter {
     // MARK: - Reporter Conformance
 
-    public static let identifier = "sonarqube"
-    public static let isRealtime = false
-    public static let description = "Reports violations in SonarQube import format."
+    static let identifier = "sonarqube"
+    static let isRealtime = false
+    static let description = "Reports violations in SonarQube import format."
 
-    public static func generateReport(_ violations: [StyleViolation]) -> String {
-        return toJSON(["issues": violations.map(dictionary(for:))])
+    static func generateReport(_ violations: [StyleViolation]) -> String {
+        toJSON(["issues": violations.map(dictionary(for:))])
     }
 
     // MARK: - Private
 
     // refer to https://docs.sonarqube.org/display/SONAR/Generic+Issue+Data
     private static func dictionary(for violation: StyleViolation) -> [String: Any] {
-        return [
+        [
             "engineId": "SwiftLint",
             "ruleId": violation.ruleIdentifier,
             "primaryLocation": [
@@ -24,10 +24,10 @@ public struct SonarQubeReporter: Reporter {
                 "filePath": violation.location.relativeFile ?? "",
                 "textRange": [
                     "startLine": violation.location.line ?? 1
-                ] as Any
+                ] as Any,
             ] as Any,
             "type": "CODE_SMELL",
-            "severity": violation.severity == .error ? "MAJOR" : "MINOR"
+            "severity": violation.severity == .error ? "MAJOR" : "MINOR",
         ]
     }
 }
