@@ -1,5 +1,5 @@
 /// The rule list containing all available rules built into SwiftLintCore.
-public let coreRules: [Rule.Type] = [
+public let coreRules: [any Rule.Type] = [
     CustomRules.self,
-    SuperfluousDisableCommandRule.self
+    SuperfluousDisableCommandRule.self,
 ]
