@@ -2,6 +2,10 @@ import ArgumentParser
 import Foundation
 import SwiftLintFramework
 
+#if swift(<5.9)
+#error("SwiftLint requires Swift 5.9 or later to build")
+#endif
+
 @main
 struct SwiftLint: AsyncParsableCommand {
     static let configuration: CommandConfiguration = {
@@ -20,9 +24,10 @@ struct SwiftLint: AsyncParsableCommand {
                 Docs.self,
                 GenerateDocs.self,
                 Lint.self,
+                Baseline.self,
                 Reporters.self,
                 Rules.self,
-                Version.self
+                Version.self,
             ],
             defaultSubcommand: Lint.self
         )
