@@ -1,6 +1,6 @@
 @testable import SwiftLintBuiltInRules
 
-class ConditionalReturnsOnNewlineRuleTests: SwiftLintTestCase {
+final class ConditionalReturnsOnNewlineRuleTests: SwiftLintTestCase {
     func testConditionalReturnsOnNewlineWithIfOnly() {
         // Test with `if_only` set to true
         let nonTriggeringExamples = [
@@ -11,13 +11,13 @@ class ConditionalReturnsOnNewlineRuleTests: SwiftLintTestCase {
             Example("if textField.returnKeyType == .Next {"),
             Example("if true { // return }"),
             Example("/*if true { */ return }"),
-            Example("guard true else { return }")
+            Example("guard true else { return }"),
         ]
         let triggeringExamples = [
             Example("↓if true { return }"),
             Example("↓if true { break } else { return }"),
             Example("↓if true { break } else {       return }"),
-            Example("↓if true { return \"YES\" } else { return \"NO\" }")
+            Example("↓if true { return \"YES\" } else { return \"NO\" }"),
         ]
 
         let description = ConditionalReturnsOnNewlineRule.description
