@@ -1,16 +1,15 @@
 import Foundation
 import SourceKittenFramework
-@_spi(TestHelper)
 @testable import SwiftLintCore
 import XCTest
 
 // swiftlint:disable file_length
 
-private let optInRules = RuleRegistry.shared.list.list.filter({ $0.1.init() is OptInRule }).map({ $0.0 })
+private let optInRules = RuleRegistry.shared.list.list.filter({ $0.1.init() is any OptInRule }).map(\.0)
 
-class ConfigurationTests: SwiftLintTestCase {
+final class ConfigurationTests: SwiftLintTestCase {
     // MARK: Setup & Teardown
-    private var previousWorkingDir: String!
+    private var previousWorkingDir: String! // swiftlint:disable:this implicitly_unwrapped_optional
 
     override func setUp() {
         super.setUp()
@@ -56,6 +55,10 @@ class ConfigurationTests: SwiftLintTestCase {
         XCTAssertEqual(config.reporter, "xcode")
         XCTAssertEqual(reporterFrom(identifier: config.reporter).identifier, "xcode")
         XCTAssertFalse(config.allowZeroLintableFiles)
+        XCTAssertFalse(config.strict)
+        XCTAssertNil(config.baseline)
+        XCTAssertNil(config.writeBaseline)
+        XCTAssertFalse(config.checkForUpdates)
     }
 
     func testInitWithRelativePathAndRootPath() {
@@ -69,6 +72,9 @@ class ConfigurationTests: SwiftLintTestCase {
         XCTAssertEqual(config.indentation, expectedConfig.indentation)
         XCTAssertEqual(config.reporter, expectedConfig.reporter)
         XCTAssertTrue(config.allowZeroLintableFiles)
+        XCTAssertTrue(config.strict)
+        XCTAssertNotNil(config.baseline)
+        XCTAssertNotNil(config.writeBaseline)
     }
 
     func testEnableAllRulesConfiguration() throws {
@@ -81,6 +87,16 @@ class ConfigurationTests: SwiftLintTestCase {
         XCTAssertEqual(configuration.rules.count, RuleRegistry.shared.list.list.count)
     }
 
+    func testOnlyRule() throws {
+        let configuration = try Configuration(
+            dict: [:],
+            onlyRule: "nesting",
+            cachePath: nil
+        )
+
+        XCTAssertEqual(configuration.rules.count, 1)
+    }
+
     func testOnlyRules() throws {
         let only = ["nesting", "todo"]
 
@@ -100,7 +116,7 @@ class ConfigurationTests: SwiftLintTestCase {
 
         let config = try Configuration(dict: ["only_rules": only, "custom_rules": customRules])
         guard let resultingCustomRules = config.rules.first(where: { $0 is CustomRules }) as? CustomRules
-            else {
+        else {
             XCTFail("Custom rules are expected to be present")
             return
         }
@@ -125,11 +141,11 @@ class ConfigurationTests: SwiftLintTestCase {
         let only = ["nesting", "todo"]
         let enabledRulesConfigDict = [
             "opt_in_rules": ["line_length"],
-            "only_rules": only
+            "only_rules": only,
         ]
         let disabledRulesConfigDict = [
             "disabled_rules": ["identifier_name"],
-            "only_rules": only
+            "only_rules": only,
         ]
         let combinedRulesConfigDict = enabledRulesConfigDict.reduce(into: disabledRulesConfigDict) { $0[$1.0] = $1.1 }
         var configuration = try? Configuration(dict: enabledRulesConfigDict)
@@ -228,12 +244,15 @@ class ConfigurationTests: SwiftLintTestCase {
     }
 
     private class TestFileManager: LintableFileManager {
-        func filesToLint(inPath path: String, rootDirectory: String? = nil) -> [String] {
+        func filesToLint(inPath path: String, rootDirectory _: String? = nil) -> [String] {
             var filesToLint: [String] = []
             switch path {
-            case "directory": filesToLint = ["directory/File1.swift", "directory/File2.swift",
-                                             "directory/excluded/Excluded.swift",
-                                             "directory/ExcludedFile.swift"]
+            case "directory": filesToLint = [
+                "directory/File1.swift",
+                "directory/File2.swift",
+                "directory/excluded/Excluded.swift",
+                "directory/ExcludedFile.swift",
+            ]
             case "directory/excluded": filesToLint = ["directory/excluded/Excluded.swift"]
             case "directory/ExcludedFile.swift": filesToLint = ["directory/ExcludedFile.swift"]
             default: XCTFail("Should not be called with path \(path)")
@@ -241,8 +260,8 @@ class ConfigurationTests: SwiftLintTestCase {
             return filesToLint.absolutePathsStandardized()
         }
 
-        func modificationDate(forFileAtPath path: String) -> Date? {
-            return nil
+        func modificationDate(forFileAtPath _: String) -> Date? {
+            nil
         }
 
         func isFile(atPath path: String) -> Bool {
@@ -252,9 +271,10 @@ class ConfigurationTests: SwiftLintTestCase {
 
     func testExcludedPaths() {
         let fileManager = TestFileManager()
-        let configuration = Configuration(includedPaths: ["directory"],
-                                          excludedPaths: ["directory/excluded",
-                                                          "directory/ExcludedFile.swift"])
+        let configuration = Configuration(
+            includedPaths: ["directory"],
+            excludedPaths: ["directory/excluded", "directory/ExcludedFile.swift"]
+        )
 
         let excludedPaths = configuration.excludedPaths(fileManager: fileManager)
         let paths = configuration.lintablePaths(inPath: "",
@@ -318,7 +338,7 @@ class ConfigurationTests: SwiftLintTestCase {
         let expectedFilenames = [
             "DirectoryLevel1.swift",
             "Level0.swift", "Level1.swift", "Level2.swift", "Level3.swift",
-            "Main.swift", "Sub.swift"
+            "Main.swift", "Sub.swift",
         ]
 
         XCTAssertEqual(Set(expectedFilenames), Set(filenames))
@@ -405,14 +425,14 @@ class ConfigurationTests: SwiftLintTestCase {
     func testConfiguresCorrectlyFromDict() throws {
         let ruleConfiguration = [1, 2]
         let config = [RuleWithLevelsMock.description.identifier: ruleConfiguration]
-        let rules = try testRuleList.allRulesWrapped(configurationDict: config).map { $0.rule }
+        let rules = try testRuleList.allRulesWrapped(configurationDict: config).map(\.rule)
         // swiftlint:disable:next xct_specific_matcher
         XCTAssertTrue(rules == [try RuleWithLevelsMock(configuration: ruleConfiguration)])
     }
 
     func testConfigureFallsBackCorrectly() throws {
         let config = [RuleWithLevelsMock.description.identifier: ["a", "b"]]
-        let rules = try testRuleList.allRulesWrapped(configurationDict: config).map { $0.rule }
+        let rules = try testRuleList.allRulesWrapped(configurationDict: config).map(\.rule)
         // swiftlint:disable:next xct_specific_matcher
         XCTAssertTrue(rules == [RuleWithLevelsMock()])
     }
@@ -421,15 +441,38 @@ class ConfigurationTests: SwiftLintTestCase {
         let configuration = try Configuration(dict: ["allow_zero_lintable_files": true])
         XCTAssertTrue(configuration.allowZeroLintableFiles)
     }
+
+    func testStrict() throws {
+        let configuration = try Configuration(dict: ["strict": true])
+        XCTAssertTrue(configuration.strict)
+    }
+
+    func testBaseline() throws {
+        let baselinePath = "Baseline.json"
+        let configuration = try Configuration(dict: ["baseline": baselinePath])
+        XCTAssertEqual(configuration.baseline, baselinePath)
+    }
+
+    func testWriteBaseline() throws {
+        let baselinePath = "Baseline.json"
+        let configuration = try Configuration(dict: ["write_baseline": baselinePath])
+        XCTAssertEqual(configuration.writeBaseline, baselinePath)
+    }
+
+    func testCheckForUpdates() throws {
+        let configuration = try Configuration(dict: ["check_for_updates": true])
+        XCTAssertTrue(configuration.checkForUpdates)
+    }
 }
 
 // MARK: - ExcludeByPrefix option tests
 extension ConfigurationTests {
     func testExcludeByPrefixExcludedPaths() {
         FileManager.default.changeCurrentDirectoryPath(Mock.Dir.level0)
-        let configuration = Configuration(includedPaths: ["Level1"],
-                                          excludedPaths: ["Level1/Level1.swift",
-                                                          "Level1/Level2/Level3"])
+        let configuration = Configuration(
+            includedPaths: ["Level1"],
+            excludedPaths: ["Level1/Level1.swift", "Level1/Level2/Level3"]
+        )
         let paths = configuration.lintablePaths(inPath: Mock.Dir.level0,
                                                 forceExclude: false,
                                                 excludeBy: .prefix)
