@@ -1,7 +1,7 @@
 @testable import SwiftLintBuiltInRules
 import XCTest
 
-class ImplicitReturnConfigurationTests: SwiftLintTestCase {
+final class ImplicitReturnConfigurationTests: SwiftLintTestCase {
     func testImplicitReturnConfigurationFromDictionary() throws {
         var configuration = ImplicitReturnConfiguration(includedKinds: Set<ImplicitReturnConfiguration.ReturnKind>())
         let config: [String: Any] = [
@@ -9,15 +9,19 @@ class ImplicitReturnConfigurationTests: SwiftLintTestCase {
             "included": [
                 "closure",
                 "function",
-                "getter"
-            ]
+                "getter",
+                "initializer",
+                "subscript",
+            ],
         ]
 
         try configuration.apply(configuration: config)
         let expectedKinds: Set<ImplicitReturnConfiguration.ReturnKind> = Set([
             .closure,
             .function,
-            .getter
+            .getter,
+            .initializer,
+            .subscript,
         ])
         XCTAssertEqual(configuration.severityConfiguration.severity, .error)
         XCTAssertEqual(configuration.includedKinds, expectedKinds)
@@ -25,9 +29,9 @@ class ImplicitReturnConfigurationTests: SwiftLintTestCase {
 
     func testImplicitReturnConfigurationThrowsOnUnrecognizedModifierGroup() {
         var configuration = ImplicitReturnConfiguration()
-        let config = ["included": ["foreach"]] as [String: Any]
+        let config = ["included": ["foreach"]] as [String: any Sendable]
 
-        checkError(Issue.unknownConfiguration(ruleID: ImplicitReturnRule.description.identifier)) {
+        checkError(Issue.invalidConfiguration(ruleID: ImplicitReturnRule.description.identifier)) {
             try configuration.apply(configuration: config)
         }
     }
