@@ -1,7 +1,7 @@
 @testable import SomeModule
 import XCTest
 
-class BoolExtensionTests: SwiftLintTestCase {
+final class BoolExtensionTests: SwiftLintTestCase {
     func testExample() {
         // some code
     }
