@@ -1,6 +1,5 @@
 import Foundation
 import SourceKittenFramework
-@_spi(TestHelper)
 import SwiftLintCore
 import XCTest
 
@@ -37,14 +36,14 @@ private extension SwiftLintFile {
             "-F",
             frameworks,
             "-sdk", sdk,
-            "-j4", path!
+            "-j4", path!,
         ]
     }
 }
 
 public extension String {
     func stringByAppendingPathComponent(_ pathComponent: String) -> String {
-        return bridge().appendingPathComponent(pathComponent)
+        bridge().appendingPathComponent(pathComponent)
     }
 }
 
@@ -55,13 +54,14 @@ public extension Configuration {
         guard let exampleConfiguration = example.configuration,
            case let .only(onlyRules) = self.rulesMode,
            let firstRule = (onlyRules.first { $0 != "superfluous_disable_command" }),
-           case let configDict = ["only_rules": onlyRules, firstRule: exampleConfiguration],
+           case let configDict: [_: any Sendable] = ["only_rules": onlyRules, firstRule: exampleConfiguration],
            let typedConfiguration = try? Configuration(dict: configDict) else { return self }
         return merged(withChild: typedConfiguration, rootDirectory: rootDirectory)
     }
 }
 
-public func violations(_ example: Example, config inputConfig: Configuration = Configuration.default,
+public func violations(_ example: Example,
+                       config inputConfig: Configuration = Configuration.default,
                        requiresFileOnDisk: Bool = false) -> [StyleViolation] {
     SwiftLintFile.clearCaches()
     let config = inputConfig.applyingConfiguration(from: example)
@@ -75,21 +75,20 @@ public func violations(_ example: Example, config inputConfig: Configuration = C
 
     let file = SwiftLintFile.testFile(withContents: stringStrippingMarkers.code, persistToDisk: true)
     let storage = RuleStorage()
-    let collecter = Linter(file: file, configuration: config, compilerArguments: file.makeCompilerArguments())
-    let linter = collecter.collect(into: storage)
+    let collector = Linter(file: file, configuration: config, compilerArguments: file.makeCompilerArguments())
+    let linter = collector.collect(into: storage)
     return linter.styleViolations(using: storage).withoutFiles()
 }
 
 public extension Collection where Element == String {
     func violations(config: Configuration = Configuration.default, requiresFileOnDisk: Bool = false)
         -> [StyleViolation] {
-            return map { SwiftLintFile.testFile(withContents: $0, persistToDisk: requiresFileOnDisk) }
+            map { SwiftLintFile.testFile(withContents: $0, persistToDisk: requiresFileOnDisk) }
                 .violations(config: config, requiresFileOnDisk: requiresFileOnDisk)
     }
 
-    @_spi(TestHelper)
     func corrections(config: Configuration = Configuration.default, requiresFileOnDisk: Bool = false) -> [Correction] {
-        return map { SwiftLintFile.testFile(withContents: $0, persistToDisk: requiresFileOnDisk) }
+        map { SwiftLintFile.testFile(withContents: $0, persistToDisk: requiresFileOnDisk) }
             .corrections(config: config, requiresFileOnDisk: requiresFileOnDisk)
     }
 }
@@ -109,7 +108,6 @@ public extension Collection where Element: SwiftLintFile {
             return requiresFileOnDisk ? violations.withoutFiles() : violations
     }
 
-    @_spi(TestHelper)
     func corrections(config: Configuration = Configuration.default, requiresFileOnDisk: Bool = false) -> [Correction] {
         let storage = RuleStorage()
         let corrections = map({ file in
@@ -126,7 +124,7 @@ public extension Collection where Element: SwiftLintFile {
 
 private extension Collection where Element == StyleViolation {
     func withoutFiles() -> [StyleViolation] {
-        return map { violation in
+        map { violation in
             let locationWithoutFile = Location(file: nil, line: violation.location.line,
                                                character: violation.location.character)
             return violation.with(location: locationWithoutFile)
@@ -136,7 +134,7 @@ private extension Collection where Element == StyleViolation {
 
 private extension Collection where Element == Correction {
     func withoutFiles() -> [Correction] {
-        return map { correction in
+        map { correction in
             let locationWithoutFile = Location(file: nil, line: correction.location.line,
                                                character: correction.location.character)
             return Correction(ruleDescription: correction.ruleDescription, location: locationWithoutFile)
@@ -149,7 +147,7 @@ public extension Collection where Element == Example {
     ///
     /// - returns: A new `Array`.
     func removingViolationMarkers() -> [Element] {
-        return map { $0.removingViolationMarkers() }
+        map { $0.removingViolationMarkers() }
     }
 }
 
@@ -166,7 +164,7 @@ private func cleanedContentsAndMarkerOffsets(from contents: String) -> (String,
 }
 
 private func render(violations: [StyleViolation], in contents: String) -> String {
-    var contents = StringView(contents).lines.map { $0.content }
+    var contents = StringView(contents).lines.map(\.content)
     for violation in violations.sorted(by: { $0.location > $1.location }) {
         guard let line = violation.location.line,
             let character = violation.location.character else { continue }
@@ -175,7 +173,8 @@ private func render(violations: [StyleViolation], in contents: String) -> String
             "\(violation.severity.rawValue): ",
             "\(violation.ruleName) Violation: ",
             violation.reason,
-            " (\(violation.ruleIdentifier))"].joined()
+            " (\(violation.ruleIdentifier))",
+        ].joined()
         if line >= contents.count {
             contents.append(message)
         } else {
@@ -190,7 +189,7 @@ private func render(violations: [StyleViolation], in contents: String) -> String
 }
 
 private func render(locations: [Location], in contents: String) -> String {
-    var contents = StringView(contents).lines.map { $0.content }
+    var contents = StringView(contents).lines.map(\.content)
     for location in locations.sorted(by: > ) {
         guard let line = location.line, let character = location.character else { continue }
         let content = NSMutableString(string: contents[line - 1])
@@ -210,16 +209,20 @@ private extension Configuration {
         let file = SwiftLintFile.testFile(withContents: cleanedBefore, persistToDisk: true)
         // expectedLocations are needed to create before call `correct()`
         let expectedLocations = markerOffsets.map { Location(file: file, characterOffset: $0) }
-        let includeCompilerArguments = self.rules.contains(where: { $0 is AnalyzerRule })
+        let includeCompilerArguments = self.rules.contains(where: { $0 is any AnalyzerRule })
         let compilerArguments = includeCompilerArguments ? file.makeCompilerArguments() : []
         let storage = RuleStorage()
-        let collecter = Linter(file: file, configuration: self, compilerArguments: compilerArguments)
-        let linter = collecter.collect(into: storage)
+        let collector = Linter(file: file, configuration: self, compilerArguments: compilerArguments)
+        let linter = collector.collect(into: storage)
         let corrections = linter.correct(using: storage).sorted { $0.location < $1.location }
         if expectedLocations.isEmpty {
-            XCTAssertEqual(
-                corrections.count, before.code != expected.code ? 1 : 0, #function + ".expectedLocationsEmpty",
-                file: before.file, line: before.line)
+            XCTAssertGreaterThanOrEqual(
+                corrections.count,
+                before.code != expected.code ? 1 : 0,
+                #function + ".expectedLocationsEmpty",
+                file: before.file,
+                line: before.line
+            )
         } else {
             XCTAssertEqual(
                 corrections.count,
@@ -262,11 +265,12 @@ private extension Configuration {
 
 private extension String {
     func toStringLiteral() -> String {
-        return "\"" + replacingOccurrences(of: "\n", with: "\\n") + "\""
+        "\"" + replacingOccurrences(of: "\n", with: "\\n") + "\""
     }
 }
 
-public func makeConfig(_ ruleConfiguration: Any?, _ identifier: String,
+public func makeConfig(_ ruleConfiguration: Any?,
+                       _ identifier: String,
                        skipDisableCommandTests: Bool = false) -> Configuration? {
     let superfluousDisableCommandRuleIdentifier = SuperfluousDisableCommandRule.description.identifier
     let identifiers: Set<String> = skipDisableCommandTests ? [identifier]
@@ -297,7 +301,7 @@ private func testCorrection(_ correction: (Example, Example),
     if let correctionConfiguration = correction.0.configuration,
         case let .only(onlyRules) = configuration.rulesMode,
         let ruleToConfigure = (onlyRules.first { $0 != SuperfluousDisableCommandRule.description.identifier }),
-        case let configDict = ["only_rules": onlyRules, ruleToConfigure: correctionConfiguration],
+        case let configDict: [_: any Sendable] = ["only_rules": onlyRules, ruleToConfigure: correctionConfiguration],
         let typedConfiguration = try? Configuration(dict: configDict) {
         config = configuration.merged(withChild: typedConfiguration, rootDirectory: configuration.rootDirectory)
     }
@@ -309,11 +313,11 @@ private func testCorrection(_ correction: (Example, Example),
 }
 
 private func addEmoji(_ example: Example) -> Example {
-    return example.with(code: "/* 👨‍👩‍👧‍👦👨‍👩‍👧‍👦👨‍👩‍👧‍👦 */\n\(example.code)")
+    example.with(code: "/* 👨‍👩‍👧‍👦👨‍👩‍👧‍👦👨‍👩‍👧‍👦 */\n\(example.code)")
 }
 
 private func addShebang(_ example: Example) -> Example {
-    return example.with(code: "#!/usr/bin/env swift\n\(example.code)")
+    example.with(code: "#!/usr/bin/env swift\n\(example.code)")
 }
 
 public extension XCTestCase {
@@ -328,7 +332,7 @@ public extension XCTestCase {
                     skipDisableCommandTests: Bool = false,
                     testMultiByteOffsets: Bool = true,
                     testShebang: Bool = true,
-                    file: StaticString = #file,
+                    file: StaticString = #filePath,
                     line: UInt = #line) {
         guard ruleDescription.minSwiftVersion <= .current else {
             return
@@ -352,7 +356,8 @@ public extension XCTestCase {
         self.verifyLint(ruleDescription, config: config, commentDoesntViolate: commentDoesntViolate,
                         stringDoesntViolate: stringDoesntViolate, skipCommentTests: skipCommentTests,
                         skipStringTests: skipStringTests, disableCommands: disableCommands,
-                        testMultiByteOffsets: testMultiByteOffsets, testShebang: testShebang)
+                        testMultiByteOffsets: testMultiByteOffsets, testShebang: testShebang,
+                        file: file, line: line)
         self.verifyCorrections(ruleDescription, config: config, disableCommands: disableCommands,
                                testMultiByteOffsets: testMultiByteOffsets)
     }
@@ -366,14 +371,14 @@ public extension XCTestCase {
                     disableCommands: [String] = [],
                     testMultiByteOffsets: Bool = true,
                     testShebang: Bool = true,
-                    file: StaticString = #file,
+                    file: StaticString = #filePath,
                     line: UInt = #line) {
         func verify(triggers: [Example], nonTriggers: [Example]) {
             verifyExamples(triggers: triggers, nonTriggers: nonTriggers, configuration: config,
-                           requiresFileOnDisk: ruleDescription.requiresFileOnDisk, file: file, line: line)
+                           requiresFileOnDisk: ruleDescription.requiresFileOnDisk)
         }
         func makeViolations(_ example: Example) -> [StyleViolation] {
-            return violations(example, config: config, requiresFileOnDisk: ruleDescription.requiresFileOnDisk)
+            violations(example, config: config, requiresFileOnDisk: ruleDescription.requiresFileOnDisk)
         }
 
         let ruleDescription = ruleDescription.focused()
@@ -414,22 +419,30 @@ public extension XCTestCase {
 
         // Disabled rule doesn't violate and disable command isn't superfluous
         for command in disableCommands {
-            let violationsPartionedByType = triggers
-                .filter { $0.testDisableCommand }
+            let disabledTriggers = triggers
+                .filter(\.testDisableCommand)
                 .map { $0.with(code: command + $0.code) }
-                .flatMap { makeViolations($0) }
-                .partitioned { $0.ruleIdentifier == SuperfluousDisableCommandRule.description.identifier }
-            XCTAssert(violationsPartionedByType.first.isEmpty,
-                      "Violation(s) still triggered although rule was disabled",
-                      file: (file), line: line)
-            XCTAssert(violationsPartionedByType.second.isEmpty,
-                      "Disable command was superfluous since no violations(s) triggered",
-                      file: (file), line: line)
+
+            for trigger in disabledTriggers {
+                let violationsPartitionedByType = makeViolations(trigger)
+                    .partitioned { $0.ruleIdentifier == SuperfluousDisableCommandRule.description.identifier }
+
+                XCTAssert(violationsPartitionedByType.first.isEmpty,
+                          "Violation(s) still triggered although rule was disabled",
+                          file: trigger.file,
+                          line: trigger.line)
+                XCTAssert(violationsPartitionedByType.second.isEmpty,
+                          "Disable command was superfluous since no violations(s) triggered",
+                          file: trigger.file,
+                          line: trigger.line)
+            }
         }
     }
 
-    func verifyCorrections(_ ruleDescription: RuleDescription, config: Configuration,
-                           disableCommands: [String], testMultiByteOffsets: Bool,
+    func verifyCorrections(_ ruleDescription: RuleDescription,
+                           config: Configuration,
+                           disableCommands: [String],
+                           testMultiByteOffsets: Bool,
                            parserDiagnosticsDisabledForTests: Bool = true) {
         let ruleDescription = ruleDescription.focused()
 
@@ -454,10 +467,10 @@ public extension XCTestCase {
         }
     }
 
-    private func verifyExamples(triggers: [Example], nonTriggers: [Example],
-                                configuration config: Configuration, requiresFileOnDisk: Bool,
-                                file callSiteFile: StaticString = #file,
-                                line callSiteLine: UInt = #line) {
+    private func verifyExamples(triggers: [Example],
+                                nonTriggers: [Example],
+                                configuration config: Configuration,
+                                requiresFileOnDisk: Bool) {
         // Non-triggering examples don't violate
         for nonTrigger in nonTriggers {
             let unexpectedViolations = violations(nonTrigger, config: config,
@@ -500,7 +513,7 @@ public extension XCTestCase {
             }
 
             // Assert locations missing violation
-            let violatedLocations = triggerViolations.map { $0.location }
+            let violatedLocations = triggerViolations.map(\.location)
             let locationsWithoutViolation = expectedLocations
                 .filter { !violatedLocations.contains($0) }
             if !locationsWithoutViolation.isEmpty {
@@ -524,7 +537,7 @@ public extension XCTestCase {
 
     // file and line parameters are first so we can use trailing closure syntax with the closure
     func checkError<T: Error & Equatable>(
-        file: StaticString = #file,
+        file: StaticString = #filePath,
         line: UInt = #line,
         _ error: T,
         closure: () throws -> Void) {
@@ -571,6 +584,6 @@ private struct FocusedRuleDescription {
 
 private extension RuleDescription {
     func focused() -> FocusedRuleDescription {
-        return FocusedRuleDescription(rule: self)
+        FocusedRuleDescription(rule: self)
     }
 }
